Package: simulateDCE
Title: Simulate Data for Discrete Choice Experiments
Version: 0.3.2
Authors@R: 
    person(given = "Julian", family = "Sagebiel", email = "julian.sagebiel@idiv.de", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-0253-6875"))
Description: Supports simulating choice experiment data for given designs. It helps to quickly test different designs against each other and compare the performance of new models. The goal of 'simulateDCE' is to make it easy to simulate choice experiment datasets using designs from 'NGENE', 'idefix' or 'spdesign'. You have to store the design file(s) in a sub-directory and need to specify certain parameters and the utility functions for the data generating process. For more details on choice experiments see Mariel et al. (2021) <doi:10.1007/978-3-030-62669-3>.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: dplyr (>= 1.1.4), evd, formula.tools, ggplot2, kableExtra,
        magrittr, mixl, psych, purrr, readr, rmarkdown, stats, utils,
        stringr, tibble, tictoc, tidyr, future, furrr, qs2, data.table,
        glue
Suggests: knitr, testthat (>= 3.0.0), rlang
Config/testthat/edition: 3
Depends: R (>= 4.1.0)
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-05-03 22:54:42 UTC; dj44vuri
Author: Julian Sagebiel [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0253-6875>)
Maintainer: Julian Sagebiel <julian.sagebiel@idiv.de>
Repository: CRAN
Date/Publication: 2026-05-04 07:00:11 UTC
Built: R 4.5.2; ; 2026-05-04 07:50:40 UTC; unix
