# Generated by roxygen2: do not edit by hand

export("%>%")
export(aggregateResults)
export(createDataset)
export(extract_b_values)
export(readdesign)
export(sim_all)
export(sim_choice)
export(simulate_choices)
import(data.table)
importFrom(dplyr,arrange)
importFrom(dplyr,mutate)
importFrom(dplyr,relocate)
importFrom(dplyr,row_number)
importFrom(dplyr,slice)
importFrom(magrittr,"%>%")
