% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{modify_bcoeff_names}
\alias{modify_bcoeff_names}
\title{Modify bcoeff Names}
\usage{
modify_bcoeff_names(bcoeff)
}
\arguments{
\item{bcoeff}{A named list of beta coefficients. The names of this list are
the coefficients used in the utility function.}
}
\value{
A list containing:
\describe{
\item{bcoeff}{The modified \code{bcoeff} list with updated names.}
\item{bcoeff_lookup}{A tibble mapping the original names to the modified names.}
}
}
\description{
This function modifies the names of beta coefficients (\code{bcoeff}) by removing
dots and underscores to ensure consistent naming. If the names are already modified,
the function skips processing.
}
\keyword{internal}
